﻿using System;
using System.IO;
using System.Net.NetworkInformation;
using System.Windows;
using Microsoft.WindowsAPICodePack.Shell;
using Microsoft.WindowsAPICodePack.Taskbar;

namespace Windows7Dev
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        private readonly JumpListCustomCategory _category1 = new JumpListCustomCategory("Custom Category 1");
        readonly string _systemFolder = Environment.GetFolderPath(Environment.SpecialFolder.System);
        private bool _isNetworkOnline;

        public Window1()
        {
            NetworkChange.NetworkAvailabilityChanged += NetworkChange_NetworkAvailabilityChanged;
            InitializeComponent();
        }

        /// <summary>
        /// Creates the jump list.
        /// </summary>
        private void CreateJumpList()
        {
            JumpList jumpList = JumpList.CreateJumpList();
            jumpList.AddCustomCategories(_category1);

            // CPU Usage
            JumpListLink cpuLink = new JumpListLink(Path.Combine(_systemFolder, "taskmgr.exe"), Utils.GetCurrentCpuUsage() + " CPU Usage")
                                       {
                                           IconReference =
                                               new IconReference(Path.Combine(_systemFolder, "taskmgr.exe"), 0)
                                       };

            jumpList.AddUserTasks(cpuLink);

            // RAM Available
            JumpListLink ramLink = new JumpListLink(Path.Combine(_systemFolder, "taskmgr.exe"), Utils.GetAvailableRAM() + " Available RAM")
                                       {
                                           IconReference =
                                               new IconReference(Path.Combine(_systemFolder, "taskmgr.exe"), 0)
                                       };
            jumpList.AddUserTasks(ramLink);


            jumpList.Refresh();
        }
        
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            SetNetworkStatus();
            CreateJumpList();
        }

        /// <summary>
        /// Sets the network status.
        /// </summary>
        void SetNetworkStatus()
        {
            _isNetworkOnline = NetworkInterface.GetIsNetworkAvailable();

            if (_isNetworkOnline)
            {
                using (StockIcon si = new StockIcon(StockIconIdentifier.MyNetwork, StockIconSizes.ShellSize, false, false))
                {
                    TaskbarManager.Instance.SetOverlayIcon(si.Icon, "");
                }
            }
            else
            {
                using (StockIcon si = new StockIcon(StockIconIdentifier.Error, StockIconSizes.ShellSize, false, false))
                {
                    TaskbarManager.Instance.SetOverlayIcon(si.Icon, "");
                }
            }
        }

        /// <summary>
        /// Handles the NetworkAvailabilityChanged event of the NetworkChange control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Net.NetworkInformation.NetworkAvailabilityEventArgs"/> instance containing the event data.</param>
        void NetworkChange_NetworkAvailabilityChanged(object sender, NetworkAvailabilityEventArgs e)
        {
            SetNetworkStatus();
        }
    }
}